aboutsummaryrefslogtreecommitdiff
path: root/include/service
diff options
context:
space:
mode:
authorLibravatar buttercat1791 <mjjurkoic@gmail.com>2024-08-08 08:53:20 -0500
committerLibravatar buttercat1791 <mjjurkoic@gmail.com>2024-08-08 08:53:20 -0500
commit5f2ac101fa951b55af699fb661866026d0998fef (patch)
tree0494f02864f270876f6f41cedfbb978a7008de7a /include/service
parentb69876b1786f5e99448266a3b74ca4404d7118fd (diff)
parent43b61ff06e18a79a3e16e38445e92b0ad678bd9f (diff)
Merge and resolve conflicting changes from master
Diffstat (limited to 'include/service')
-rw-r--r--include/service/nostr_service_base.hpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/service/nostr_service_base.hpp b/include/service/nostr_service_base.hpp
index c3f8c99..f1b91d1 100644
--- a/include/service/nostr_service_base.hpp
+++ b/include/service/nostr_service_base.hpp
@@ -58,7 +58,8 @@ public:
* @brief Queries all open relay connections for events matching the given set of filters, and
* returns all stored matching events returned by the relays.
* @param filters The filters to use for the query.
* @returns A vector of all events matching the filters from all open relay connections.
* @remark This method runs until the relays send an EOSE message, indicating they have no more
* stored events matching the given filters. When the EOSE message is received, the method
* will close the subscription for each relay and return the received events.
@@ -66,7 +67,7 @@ public:
* set on the filters in the range 1-64, inclusive. If no valid limit is given, it will be
* defaulted to 16.
*/
- virtual std::vector<std::shared_ptr<data::Event>> queryRelays(
+ virtual std::future<std::vector<std::shared_ptr<data::Event>>> queryRelays(
std::shared_ptr<data::Filters> filters) = 0;
/**
@@ -58,7 +58,8 @@ public:
* returns all stored matching events returned by the relays.
* @param filters The filters to use for the query.
- * @returns A vector of all events matching the filters from all open relay connections.
+ * @returns A std::future that will eventually hold a vector of all events matching the filters
+ * from all open relay connections.
* @remark This method runs until the relays send an EOSE message, indicating they have no more
* stored events matching the given filters. When the EOSE message is received, the method